# automatically generated by the FlatBuffers compiler, do not modify

# namespace: openmeteo_sdk

class Model(object):
    undefined = 0
    best_match = 1
    gfs_seamless = 2
    gfs_global = 3
    gfs_hrrr = 4
    meteofrance_seamless = 5
    meteofrance_arpege_seamless = 6
    meteofrance_arpege_world = 7
    meteofrance_arpege_europe = 8
    meteofrance_arome_seamless = 9
    meteofrance_arome_france = 10
    meteofrance_arome_france_hd = 11
    jma_seamless = 12
    jma_msm = 13
    jms_gsm = 14
    jma_gsm = 15
    gem_seamless = 16
    gem_global = 17
    gem_regional = 18
    gem_hrdps_continental = 19
    icon_seamless = 20
    icon_global = 21
    icon_eu = 22
    icon_d2 = 23
    ecmwf_ifs04 = 24
    metno_nordic = 25
    era5_seamless = 26
    era5 = 27
    cerra = 28
    era5_land = 29
    ecmwf_ifs = 30
    gwam = 31
    ewam = 32
    glofas_seamless_v3 = 33
    glofas_forecast_v3 = 34
    glofas_consolidated_v3 = 35
    glofas_seamless_v4 = 36
    glofas_forecast_v4 = 37
    glofas_consolidated_v4 = 38
    gfs025 = 39
    gfs05 = 40
    CMCC_CM2_VHR4 = 41
    FGOALS_f3_H_highresSST = 42
    FGOALS_f3_H = 43
    HiRAM_SIT_HR = 44
    MRI_AGCM3_2_S = 45
    EC_Earth3P_HR = 46
    MPI_ESM1_2_XR = 47
    NICAM16_8S = 48
    cams_europe = 49
    cams_global = 50
    cfsv2 = 51
    era5_ocean = 52
    cma_grapes_global = 53
    bom_access_global = 54
    bom_access_global_ensemble = 55
    arpae_cosmo_seamless = 56
    arpae_cosmo_2i = 57
    arpae_cosmo_2i_ruc = 58
    arpae_cosmo_5m = 59
    ecmwf_ifs025 = 60
    ecmwf_aifs025 = 61
    gfs013 = 62
    gfs_graphcast025 = 63
    ecmwf_wam025 = 64
    meteofrance_wave = 65
    meteofrance_currents = 66
    ecmwf_wam025_ensemble = 67
    ncep_gfswave025 = 68
    ncep_gefswave025 = 69
    knmi_seamless = 70
    knmi_harmonie_arome_europe = 71
    knmi_harmonie_arome_netherlands = 72
    dmi_seamless = 73
    dmi_harmonie_arome_europe = 74
    metno_seamless = 75
    era5_ensemble = 76
    ecmwf_ifs_analysis = 77
    ecmwf_ifs_long_window = 78
    ecmwf_ifs_analysis_long_window = 79
    ukmo_global_deterministic_10km = 80
    ukmo_uk_deterministic_2km = 81
    ukmo_seamless = 82
    ncep_gfswave016 = 83
    ncep_nbm_conus = 84
    ukmo_global_ensemble_20km = 85
    ecmwf_aifs025_single = 86
    jma_jaxa_himawari = 87
    eumetsat_sarah3 = 88
    eumetsat_lsa_saf_msg = 89
    eumetsat_lsa_saf_iodc = 90
    satellite_radiation_seamless = 91
    kma_gdps = 92
    kma_ldps = 93
    kma_seamless = 94
    italia_meteo_arpae_icon_2i = 95
