from __future__ import annotations

import flatbuffers
import numpy as np

import flatbuffers
import typing

uoffset: typing.TypeAlias = flatbuffers.number_types.UOffsetTFlags.py_type

class Variable(object):
  undefined: int
  apparent_temperature: int
  cape: int
  cloud_cover: int
  cloud_cover_high: int
  cloud_cover_low: int
  cloud_cover_mid: int
  daylight_duration: int
  dew_point: int
  diffuse_radiation: int
  diffuse_radiation_instant: int
  direct_normal_irradiance: int
  direct_normal_irradiance_instant: int
  direct_radiation: int
  direct_radiation_instant: int
  et0_fao_evapotranspiration: int
  evapotranspiration: int
  freezing_level_height: int
  growing_degree_days: int
  is_day: int
  latent_heat_flux: int
  leaf_wetness_probability: int
  lifted_index: int
  lightning_potential: int
  precipitation: int
  precipitation_hours: int
  precipitation_probability: int
  pressure_msl: int
  rain: int
  relative_humidity: int
  runoff: int
  sensible_heat_flux: int
  shortwave_radiation: int
  shortwave_radiation_instant: int
  showers: int
  snow_depth: int
  snow_height: int
  snowfall: int
  snowfall_height: int
  snowfall_water_equivalent: int
  sunrise: int
  sunset: int
  soil_moisture: int
  soil_moisture_index: int
  soil_temperature: int
  surface_pressure: int
  surface_temperature: int
  temperature: int
  terrestrial_radiation: int
  terrestrial_radiation_instant: int
  total_column_integrated_water_vapour: int
  updraft: int
  uv_index: int
  uv_index_clear_sky: int
  vapour_pressure_deficit: int
  visibility: int
  weather_code: int
  wind_direction: int
  wind_gusts: int
  wind_speed: int
  vertical_velocity: int
  geopotential_height: int
  wet_bulb_temperature: int
  river_discharge: int
  wave_height: int
  wave_period: int
  wave_direction: int
  wind_wave_height: int
  wind_wave_period: int
  wind_wave_peak_period: int
  wind_wave_direction: int
  swell_wave_height: int
  swell_wave_period: int
  swell_wave_peak_period: int
  swell_wave_direction: int
  pm10: int
  pm2p5: int
  dust: int
  aerosol_optical_depth: int
  carbon_monoxide: int
  nitrogen_dioxide: int
  ammonia: int
  ozone: int
  sulphur_dioxide: int
  alder_pollen: int
  birch_pollen: int
  grass_pollen: int
  mugwort_pollen: int
  olive_pollen: int
  ragweed_pollen: int
  european_aqi: int
  european_aqi_pm2p5: int
  european_aqi_pm10: int
  european_aqi_nitrogen_dioxide: int
  european_aqi_ozone: int
  european_aqi_sulphur_dioxide: int
  us_aqi: int
  us_aqi_pm2p5: int
  us_aqi_pm10: int
  us_aqi_nitrogen_dioxide: int
  us_aqi_ozone: int
  us_aqi_sulphur_dioxide: int
  us_aqi_carbon_monoxide: int
  sunshine_duration: int
  convective_inhibition: int
  shortwave_radiation_clear_sky: int
  global_tilted_irradiance: int
  global_tilted_irradiance_instant: int
  ocean_current_velocity: int
  ocean_current_direction: int
  cloud_base: int
  cloud_top: int
  mass_density: int
  boundary_layer_height: int
  formaldehyde: int
  glyoxal: int
  non_methane_volatile_organic_compounds: int
  pm10_wildfires: int
  peroxyacyl_nitrates: int
  secondary_inorganic_aerosol: int
  residential_elementary_carbon: int
  total_elementary_carbon: int
  pm2_5_total_organic_matter: int
  sea_salt_aerosol: int
  nitrogen_monoxide: int
  thunderstorm_probability: int
  rain_probability: int
  freezing_rain_probability: int
  ice_pellets_probability: int
  snowfall_probability: int
  carbon_dioxide: int
  methane: int
  sea_level_height_msl: int
  sea_surface_temperature: int
  invert_barometer_height: int
  hail: int
  albedo: int
  precipitation_type: int
  convective_cloud_base: int
  convective_cloud_top: int
  snow_depth_water_equivalent: int
  secondary_swell_wave_height: int
  secondary_swell_wave_period: int
  secondary_swell_wave_peak_period: int
  secondary_swell_wave_direction: int
  tertiary_swell_wave_height: int
  tertiary_swell_wave_period: int
  tertiary_swell_wave_peak_period: int
  tertiary_swell_wave_direction: int

